@@ -34,16 +34,18 @@ NULL
 #' 
 #' @param path path to specific API request URL 
 #' @param query query list 
+#' @param \dots Additional arguments passed to \code{\link[httr]{GET}}.
+#' 
 #' @return list
 
 abbyy_GET <- 
-function(path, query) {
+function(path, query, ...) {
 
 	app_id = Sys.getenv("AbbyyAppId"); app_pass = Sys.getenv("AbbyyAppPassword")
 	if(identical(app_id, "") | identical(app_pass, "")) stop("Please set application id and password using setapp(c('app_id', 'app_pass')).")
 	
 	auth <- authenticate(app_id, app_pass)
-	res <- GET("https://cloud.ocrsdk.com/", path=path, auth, query=query)
+	res <- GET("https://cloud.ocrsdk.com/", path=path, auth, query=query, ...)
 	abbyy_check(res)
 	res <- xmlToList(content(res, as="text"))
 
@@ -57,16 +59,18 @@ function(path, query) {
 #' @param path path to specific API request URL 
 #' @param query query list
 #' @param body passing image through body 
+#' @param \dots Additional arguments passed to \code{\link[httr]{POST}}.
+#' 
 #' @return list
 
 abbyy_POST <- 
-function(path, query, body="") {
+function(path, query, body="", ...) {
 
 	app_id = Sys.getenv("AbbyyAppId"); app_pass = Sys.getenv("AbbyyAppPassword")
 	if(identical(app_id, "") | identical(app_pass, "")) stop("Please set application id and password using setapp(c('app_id', 'app_pass')).")
 	
 	auth <- authenticate(app_id, app_pass)
-	res <- POST("https://cloud.ocrsdk.com/", path=path, auth, query=query, body=body)
+	res <- POST("https://cloud.ocrsdk.com/", path=path, auth, query=query, body=body, ...)
 	abbyy_check(res)
 	res <- xmlToList(content(res, as="text"))
 
