@@ -4,6 +4,8 @@
 #' when the application credits expire etc. The function prints the details, and returns a 
 #' data.frame with the details.
 #' 
+#' @param \dots Additional arguments passed to \code{\link{abbyy_GET}}.
+#' 
 #' @return A data.frame with the following fields: Name of the Application (name), 
 #' No. of pages remaining (pages), No. of fields remaining (fields), 
 #' when the application credits expire (expires) and type of application (type). 
@@ -13,15 +15,13 @@
 #' @references \url{http://ocrsdk.com/documentation/apireference/getApplicationInfo/}
 #' @references \url{http://ocrsdk.com/schema/appInfo-1.0.xsd}
 #' 
-#' @usage getAppInfo()
-#' 
 #' @examples \dontrun{
 #' getAppInfo()
 #' }
 
-getAppInfo <- function() {
+getAppInfo <- function(...) {
 
-	appinfo <- abbyy_GET("getApplicationInfo", query="")[[1]]
+	appinfo <- abbyy_GET("getApplicationInfo", query="", ...)[[1]]
 
 	appinfo <- as.data.frame(appinfo)
 
