@@ -5,6 +5,8 @@
 #' The function returns a data.frame with all the task details: id (task id), registrationTime, statusChangeTime, status (Submitted, Queued, InProgress, Completed, ProcessingFailed, Deleted, NotEnoughCredits), filesCount (No. of files), credits, resultUrl (URL for the processed file if applicable)
 #' 
 #' @param taskId Required, Id of the task
+#' @param \dots Additional arguments passed to \code{\link{abbyy_GET}}.
+#' 
 #' @return A data frame with all the available details about the task
 #' @export
 #' @references \url{http://ocrsdk.com/documentation/apireference/getTaskStatus/} 
@@ -12,12 +14,12 @@
 #' getTaskStatus(taskId="task_id")
 #' }
 
-getTaskStatus <- function(taskId = NULL) {
+getTaskStatus <- function(taskId = NULL, ...) {
 	
 	if (is.null(taskId)) stop("Must specify taskId")
 	
 	querylist <- list(taskId = taskId)	
-	taskdetails <- abbyy_GET("getTaskStatus", query=querylist)
+	taskdetails <- abbyy_GET("getTaskStatus", query=querylist, ...)
 
 	resdf <- as.data.frame(do.call(rbind, taskdetails)) # collapse to a data.frame
 
