@@ -6,21 +6,21 @@
 #' No more than 100 tasks can be returned at one method call. 
 #' The function prints number of finished tasks by default.
 #' 
+#' @param \dots Additional arguments passed to \code{\link{abbyy_GET}}.
+#' 
 #' @return A data frame with the following columns: id (task id), registrationTime, statusChangeTime, 
 #' status (Completed), filesCount (No. of files), credits, resultUrl (URL for the processed file)
 #' 
 #' @export
 #' @references \url{http://ocrsdk.com/documentation/apireference/listFinishedTasks/}
 #' 
-#' @usage listFinishedTasks()
-#' 
 #' @examples \dontrun{
 #' listFinishedTasks()
 #' }
 
-listFinishedTasks <- function() {
+listFinishedTasks <- function(...) {
 	
-	tasklist <- abbyy_GET("listFinishedTasks", query="")	
+	tasklist <- abbyy_GET("listFinishedTasks", query="", ...)	
 
 	# Names of return df.
 	frame_names <- c("id", "registrationTime", "statusChangeTime", "status", "filesCount", "credits", "resultUrl")
